plugin Package
==============

:mod:`base_plugin` Module
-------------------------

.. automodule:: ivy.plugin.base_plugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`parallel_plugin_collection` Module
----------------------------------------

.. automodule:: ivy.plugin.parallel_plugin_collection
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`plugin_factory` Module
----------------------------

.. automodule:: ivy.plugin.plugin_factory
    :members:
    :undoc-members:
    :show-inheritance:

